.. include:: ../README.rst

API
===

.. autofunction:: cherrypy_cors.expose
.. autofunction:: cherrypy_cors.expose_public
.. autofunction:: cherrypy_cors.preflight
.. autofunction:: cherrypy_cors.install

.. autoclass:: cherrypy_cors.CORS



.. _Access-Control-Allow-Origin: http://www.w3.org/TR/cors/#access-control-allow-origin-response-header
.. _Access-Control-Allow-Credentials: http://www.w3.org/TR/cors/#access-control-allow-credentials-response-header
.. _Access-Control-Expose-Headers: http://www.w3.org/TR/cors/#access-control-allow-headers-response-header
.. _Access-Control-Max-Age: http://www.w3.org/TR/cors/#access-control-max-age-response-header
.. _Access-Control-Allow-Methods: http://www.w3.org/TR/cors/#access-control-allow-methods-response-header
.. _Access-Control-Allow-Headers: http://www.w3.org/TR/cors/#access-control-allow-headers-response-header
.. _Origin: http://www.w3.org/TR/cors/#origin-request-header
.. _Access-Control-Request-Method: http://www.w3.org/TR/cors/#access-control-request-method-request-header
.. _Access-Control-Request-Headers: http://www.w3.org/TR/cors/#access-control-request-headers-request-header
.. _Vary: http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.44
.. _Method Dispatcher: https://cherrypy.readthedocs.org/en/latest/refman/_cpdispatch.html#cherrypy._cpdispatch.MethodDispatcher
.. _Object Dispatcher: https://cherrypy.readthedocs.org/en/latest/refman/_cpdispatch.html#cherrypy._cpdispatch.Dispatcher
.. _preflight: http://www.w3.org/TR/cors/#cross-origin-request-with-preflight-0